0.10.21 UPD 28 Ağu Windows, Linux

İndir Team Red Miner

TeamRedMiner — Eksiksiz kılavuz

Seçenekler:

  -a, --algo=ALGORITHM      Madencilik algoritmasını seçer.  Şu anda kullanılabilenler:
                              ethash            (eth, etp, diğerleri)
                              etchash           (etc, -a ethash --eth_variant_mode=etchash için takma ad)
                              kawpow            (ravencoin)
                              firopow           (firo)
                              mtp_firopow       (firopow veya mtp'yi seçer ve 26 Ekim 2021'deki fork'ta madenci yazılımını kapatır)
                              autolykos2        (ergo)
                              verthash          (vtc)
                              ton               (ton)
                              kas               (kaspa)
                              nimiq             (nimiq)
                              lyra2z
                              phi2              (lux, argoneum)
                              lyra2rev3
                              x16r
                              x16rv2
                              x16s              (pgn, xsh)
                              x16rt             (gin)
                              mtp               (firopow fork'undan önceki zcoin/firo)
                              cuckatoo31_grin   (grin)
                              cuckarood29_grin  (grin)
                              cnv8
                              cnr               (eski monero)
                              cnv8_half         (stellite, masari)
                              cnv8_dbl          (x-cash)
                              cnv8_rwz          (graft)
                              cnv8_trtl         (eski turtlecoin, loki)
                              cnv8_upx2         (uplexa)
                              cn_heavy          (klasik CN heavy)
                              cn_haven          (haven)
                              cn_saber          (bittube)
                              cn_conceal        (conceal)
                              trtl_chukwa       (turtlecoin)
                              trtl_chukwa2      (turtlecoin)

  -h, --help                Bu yardım mesajını gösterir ve çıkar.
      --debug               Hata ayıklama (debug) log çıktısını etkinleştirir.
      --hardware=HW_LIST    Madenci yazılımının hangi donanım türlerinde çalışmayı denemesi gerektiğini virgülle ayrılmış bir listede belirtir.
                              Şu anda desteklenen değerler 'gpu' ve 'fpga'dır.  Örneğin:
                                --hardware=gpu,fpga
      --benchmark           Benchmark modunu etkinleştirir.  Tanımlanan tüm havuzlar yok sayılır ve otomatik olarak tek bir
                              dahili sahte havuz eklenir.  eth ve kawpow gibi algoritmaları belirli epoch ve blok
                              yüksekliklerinde test etmek için --eth_epoch=456 ve --prog_height=123456 gibi algoritmaya özgü argümanlar da eklemeniz gerekir.
      --disable_colors      Konsol çıktısındaki renkleri devre dışı bırakır.
      --force_colors        Terminal desteklemiyor gibi görünse bile konsolda renkli çıktıyı zorlar.
      --api_listen=IP:PORT  sgminer uyumlu API'yi etkinleştirir. IP:PORT isteğe bağlıdır. Belirtilirse IP:PORT çifti
                              dinlenecek arayüz(ler)i ve portu belirler. Varsayılan 127.0.0.1:4028'dir. Dışarıdan
                              erişim için örneğin 0.0.0.0:4028 kullanın. Yalnızca portu belirtmek de
                              geçerlidir, örneğin 4029.  Artık ayrı uç noktalar için bu argüman birden fazla kez kullanılabilir.
      --api2_listen=IP:PORT Dual madencilik kurulumları için ikinci bir API portunu etkinleştirir.  Bu API uç noktası, tıpkı
                              paralel çalışan iki ayrı madenci yazılımı örneği varmış gibi dual madencilik algoritmasının
                              verilerini sağlar.  Varsayılan ayar 127.0.0.1:4029'dur, yani port 4028 değil 4029'dur.  Kendi
                              seçiminizi belirtmek için argüman --api_listen ile aynı biçimde yazılır.  Artık ayrı uç noktalar
                               için bu argüman birden fazla kez kullanılabilir.
      --cm_api_listen=IP:PORT Claymore uyumlu API'yi etkinleştirir. IP:PORT isteğe bağlıdır. Belirtilirse IP:PORT çifti
                              dinlenecek arayüz(ler)i ve portu belirler. Varsayılan 127.0.0.1:3333'tür. Dışarıdan
                              erişim için örneğin 0.0.0.0:3333 kullanın. Yalnızca portu belirtmek de
                              geçerlidir, örneğin 3334.
      --cm_api_password=PSW CM uyumlu API arayüzü için gerekli parolayı ayarlar.
      --log_file(=FILENAME) Madenci yazılımı çıktısının FILENAME ile belirtilen dosyaya loglanmasını etkinleştirir.  Dosya adı
                              verilmezse madenci yazılımı, geçerli çalışma dizinindeki trm_<algo>_<yyyymmdd_hhmmss>.log
                              dosyasına log yazar.  Log dosyası zaten varsa madenci yazılımı sonuna ekleme yapar.
  -l, --log_interval=SEC    GPU hashrate'lerinin ortalamasının alınması ve yazdırılması için saniye cinsinden zaman aralığını ayarlar.
                              SEC aralığı saniye cinsinden belirler ve > 0 olmalıdır.
      --log_rotate=SZ[,CNT] Log rotasyonunu etkinleştirir. SZ değeri, aşıldığında yeni bir log dosyası oluşturulacak log
                              boyutunu belirler.  SZ değeri 'k', 'M' ve 'G' soneklerini destekler ve değeri sırasıyla
                              1024, 1048576 ve 1073741824 ile çarpar. İsteğe bağlı CNT değeri, saklanacak eski log
                              dosyalarının maksimum sayısını belirler.  Örneğin '--log_rotate=4M,16' seçeneği, mevcut
                              log dosyası 4194304 baytı aştığında madenci yazılımının yeni bir log dosyasına geçmesini
                              sağlar; madenci yazılımı bu tür son 16 dosyayı saklar ve daha eskilerini
                              siler.
      --short_stats         Her hashrate çıktısındaki tam GPU durum çıktısını, 0.7.10 öncesinde olduğu gibi devre dışı bırakır.
      --dev_location=LOC    Dev fee bağlantısı için belirli bir konum seçer. Bunu yalnızca madenci yazılımının sürekli
                              dev fee bağlantı sorunları bildirdiğini görüyorsanız kullanın. Bağlantı
                              yönetimi normalde tüm konumlarda iyi çalışır. Kullanılabilir seçenekler:
                              world     - Çin anakarası hariç dünyanın her yeri.
                              non-gcp   - Google hizmetlerine erişimin engellendiği ülkeler (ör. İran, Küba).
                              cn        - Çin anakarası.
                              eu        - AB, Rusya, Ukrayna ve yakın çevresi.
                              us        - ABD, Kanada, Orta/Güney Amerika.
                              asia      - Çin hariç Asya.
      --enable_compute      (Yalnızca Windows) Gerekli GPU'larda compute modunu etkinleştirir ve crossfire'ı devre dışı bırakır.
      --long_timestamps     Loglarda yalnızca saniye yerine mikrosaniyeli zaman damgalarını etkinleştirir.
      --restart_gpus        (Yalnızca Windows) Madencilikten önce yapılandırılmış tüm GPU'ları yeniden başlatır, yani PCI cihazını devre dışı bırakıp etkinleştirir.
      --uac                 (Yalnızca Windows) Madenci yazılımı GPU'ları yeniden başlatmak gibi görevleri yürütürken yetki yükseltmeyi etkinleştirir.
                              Madenci yazılımını doğrudan Yönetici olarak çalıştırarak bundan her zaman kaçınabilirsiniz.  Bu,
                              standart Windows yetki yükseltme penceresini açar, bu yüzden 'Evet'e tıklamak için başında olmanız gerekir.
                              Bu etkin değilse, madenci yazılımı temel bir kullanıcı hesabıyla çalışırken Yönetici yetkisi
                              gerektiren görevler başarısız olur.
      --high_score          Madenci yazılımı başladığından beri bulunan en iyi 15 share'in istatistik çıktısında gösterilmesini etkinleştirir.
                              Not: bu, tüm algoritmalar için etkin olmayabilir.
      --allow_dup_bus_ids   Aynı PCI bus ID'sini kullanan birden fazla GPU'ya izin verir.  Bu yalnızca Radeon Pro Duo
                              kartları ve benzeri donanımlar için kullanılmalıdır; normalde bozuk bir OpenCL ortamının göstergesidir.
      --dns_https=URL       DNS-over-HTTPS kullanarak havuz DNS çözümlemesini etkinleştirir.  Bu deneysel bir özelliktir.  TRM
                              yalnızca JSON tabanlı varyantı destekler, daha sonra RFC8484'te tanımlanan mekanizmayı desteklemez.  Kullanıcı,
                              yöntem adı dahil tam https URL'sini vermelidir.  Ham IP adresleri yerine host adları
                              verilebilir, ancak bu host adları sistem DNS'i kullanılarak çözümlenir.
                              Çalıştığı doğrulanmış birkaç örnek:

                              --dns_https=https://8.8.8.8/resolve           (Google DNS)
                              --dns_https=https://9.9.9.9:5053/dns-query    (Quad9)
                              --dns_https=https://1.1.1.1/dns-query         (Cloudflare DNS hizmeti)
      --dns_https_sni=HOST  --dns_https argümanı kullanıldığında varsayılan davranış, SSL/TLS bağlantısında SNI
                              göndermemektir.  Bu argümanla herhangi bir SNI'nin gönderilmesini zorlayabilirsiniz.  Bunun
                              ileri düzey bir ağ argümanı olduğunu ve çoğu kullanıcının buna ihtiyaç duymadığını unutmayın.
      --kernel_vm_mode=X    (Yalnızca Linux). Debian/Ubuntu tabanlı Linux sistemlerinde /etc/default/grub içindeki gerekli
                              çekirdek (kernel) parametrelerinin ayarlanmasını otomatikleştirir.  Bu, madencilik dağıtımlarının çoğunu kapsar.  Çekirdek
                              parametreleri değiştirildiğinde sistem /sbin/reboot ile otomatik olarak yeniden başlatılabilir.  Doğru
                              parametreler zaten yerindeyse madenci yazılımı ve yardımcı betik hiçbir şey yapmaz. Bu, bu
                              argümanın komut satırında her zaman bulunabileceği anlamına gelir.  Geçerli değerler:
                                N  -  mod yapılandırılmamış, C- veya R-modu için mevcut parametreleri kaldırır.  Değişiklikte yeniden başlatma yok.
                                C  -  eski Radeon VII C-modu.  Değişiklikte yeniden başlatma yok.
                                R  -  Polaris hariç tüm GPU'lar için yeni R-modu.  Değişiklikte yeniden başlatma yok.
                                RN -  mod yapılandırılmamış, C- veya R-modu için mevcut parametreleri kaldırır.  Değişiklikte yeniden başlatır.
                                RC -  eski Radeon VII C-modu.  Değişiklikte yeniden başlatır.
                                RR -  Polaris hariç tüm GPU'lar için yeni R-modu.  Değişiklikte yeniden başlatır.
      --kernel_vm_mode_script=X  (Yalnızca Linux).  Yeni çekirdek modu parametrelerini ayarlamak için çağrılacak betiği belirtir.
                              Betik, madenci yazılımının dağıtım paketinde bulunan ubuntu_mode_script.sh adlı varsayılan TRM
                              betiği gibi davranmalıdır.  Bu argüman normalde gerekli olmamalıdır.
      --gpu_sdma=on|off     Sürücünün GPU'ya/GPU'dan bellek kopyalamak için doğrudan sdma işlemlerini kullanıp kullanmayacağını
                              kontrol eder. Bu argüman yalnızca çok özel durumlarda gereklidir. Örneğin AMD BC-250
                              sdma'yı desteklemez ve --gpu_sdma=off gerektirir. GPU başlatma sırasında doğrudan donmalar
                              yaşıyorsanız ama diğer madenci yazılımları veya eski TRM sürümleri sorunsuz çalışıyorsa --gpu_sdma=off deneyin.
                              Bu ayar bir ortam ayarıdır ve tüm GPU'ları kontrol eder.

Havuz yapılandırma seçenekleri:

  -o, --url=URL             Havuz URL'sini ayarlar.  Şu anda stratum+tcp ve stratum+ssl URL'leri desteklenir.
                              Bu seçenek her ek kez belirtildiğinde yeni bir havuz yapılandırması başlatılır.
                              Havuza özel seçeneklerin (-u, -p gibi) her yeni havuz için açıkça yeniden
                              belirtilmesi gerekir.  (start_multipool.sh/bat örnek dosyasına bakın)
                              Madenci yazılımının çoklu havuz stratejisi --pool_strategy seçeneğiyle ayarlanır.
                              SSL uç noktasına bir SNI host adı iletmeniz gereken ileri düzey SSL/TLS kurulumları için
                              özel destek de vardır. Örneğin bu, birden fazla host için ön yüz görevi gören ve hangisi
                              için sertifika sunacağını bilmesi gereken SSL uç noktaları için gereklidir. Bu gibi
                              durumlarda şu biçimi kullanın:
                              -o stratum+ssl://pool.tunnel.com/pool.realhostname.com:3333
                              Bu, pool.tunnel.com:3333'e bağlanır, ancak SSL el sıkışma aşamasında SNI host adı olarak
                              pool.realhostname.com'u iletir. İki host adı elbette aynı da olabilir.
  -u, --user=USERNAME       Havuz yetkilendirmesi için kullanıcı adını ayarlar.
  -p, --pass=PASSWORD       Havuz yetkilendirmesi için parolayı ayarlar.
      --pool_force_ensub    Madenci yazılımının tanımadığı, destekleyen havuzlar için extranonce subscribe isteğini zorlar.
      --pool_no_ensub       Madenci yazılımının havuza extranonce subscribe isteği göndermesini engeller.
      --pool_broken_rpc     Madenci yazılımına, havuz bağlantısında yanıt bekleyen yalnızca tek bir RPC isteğine izin
                              vermesini söyler.  Bu, RPC ID'leriyle ilgili JSON-RPC spesifikasyonunu ihlal eden
                              havuzlar için geçici bir çözümdür.
      --pool_ratio=RATIO    Birden fazla havuz 'load_balance' veya 'quota' havuz stratejileriyle kullanıldığında
                              havuzlar arasındaki hashrate oranını ayarlar (bkz. --pool_strategy).  Varsayılan olarak tüm
                              havuzlar 1 oran değerini kullanır.  Örneğin bu seçenek yalnızca bir havuzda 2 değeriyle
                              kullanılırsa o havuz diğer havuzların iki katı hashrate alır, çünkü onların oranı
                              hâlâ varsayılan 1 değeridir.
      --pool_debug          Tüm havuz trafiğini loglar.

Genel havuz seçenekleri:

      --pool_connect_TO=SEC Havuza bağlanma denemesi için zaman aşımını ayarlar. SEC, saniye cinsinden bekleme
                              süresidir. Varsayılan 10'dur.
      --pool_rpc_TO=SEC     Madenci yazılımının havuza gönderilen yanıtsız bir RPC için ne kadar bekleyeceğini ayarlar.  Bu
                              sürenin sonunda madenci yazılımı havuza yeniden bağlanır.  SEC, saniye cinsinden bekleme süresidir.
                              Varsayılan 60'tır.
      --pool_max_rejects=N  Havuz art arda N share'i reddederse havuz bağlantısı sıfırlanır. Bu, kullanıcının bağlantısını
                              kesmeden madencilik oturumlarını geçersiz kılan havuzlara karşı koruma içindir.
                              Varsayılan değer 5'tir.
      --pool_share_limit_ms=N  Havuz bir share'i kabul veya reddetmek için N ms'den uzun sürerse mevcut bağlantıyı
                              sonlandırır ve yeniden bağlanır.  Bu, bazı sunucularında sık sık sorun yaşanan havuzlar
                              içindir; yeniden bağlanmak, yük dengeleme ile farklı ve umarız daha iyi bir sunucuya
                              yönlendirilmek demektir.  Varsayılan değer: zaman aşımı yok.
      --pool_strategy=STRAT Birden fazla havuzla çalışırken havuz seçme stratejisini ayarlar.  Kullanılabilir
                              değerler: priority, load_balance, quota ve min_epoch.  Varsayılan priority'dir.
                              priority: Madenci yazılımı havuzları listelendikleri sırayla kullanır, yalnızca
                                önceki havuz bağlantı kuramazsa bir sonrakine geçer.
                              load_balance: Madenci yazılımı hashrate'i o anda bağlı tüm havuzlar arasında eşit
                                olarak dağıtır.  Havuzlar arasındaki hashrate oranı --pool_ratio ile ayarlanabilir.
                              quota: Madenci yazılımı tamamlanan toplam hash sayısını tüm havuzlar arasında eşit
                                olarak dengeler.  Bir havuzun bağlantısı kesilir ve sonra yeniden bağlanırsa, madenci yazılımı
                                her havuzun toplam hash'i dengelenene kadar hashrate'i o havuza aktarır.
                                Havuzlar arasındaki hashrate oranı --pool_ratio ile ayarlanabilir.
                              min_epoch: ETH + ZIL geçiş stratejisi.  Madenci yazılımı her zaman bağlı tüm havuzlar
                                arasında en düşük epoch'u kazar, eşitlik durumunda ise ilk bağlanan havuzu.
                                Bu nedenle ETH madencilik havuzunuzu ilk/birincil havuz, ardından ZIL havuzunu
                                ikinci havuz olarak belirtin.  Bu strateji için 'eth_zil' adını da kullanabilirsiniz.
      --no_ntime_roll       Madenci yazılımının blok başlığındaki ntime'ı değiştirmesini (roll) engeller, yalnızca havuzun
                              verdiği değeri kullanır. x16rt kazarken bazı havuzlar için bunun etkinleştirilmesi gerekir.
      --no_stale_submit     Madenci yazılımının havuzun en güncel işine ait olmayan share'leri göndermesini engeller.

GPU seçenekleri:

      --platform=INDEX      Kullanılacak OpenCL platformunun indeksini ayarlar. Belirtilmezse platform
                              otomatik olarak algılanır. Birden fazla platformlu Linux yalnızca --platform argümanı
                              kullanılmadan, bunun yerine --bus_reorder eklenerek desteklenir.
  -d, --devices=DEVLIST     Algılanan listeden kullanılacak GPU cihazlarını ayarlar. DEVLIST, cihaz indekslerinin virgülle
                              ayrılmış bir listesi olmalıdır, ör. -d 0,1,2,4.  Belirtilmezse platform(lar)daki tüm
                              cihazlar kullanılır.  NOT: varsayılan olarak cihazlar PCIe bus sırasına göre
                              sıralanır. İndeksleri görmek için --list_devices kullanın.
      --init_style=1/2/3    Başlatma stilini belirtir (varsayılan 1'dir):
                              1: Bir seferde bir GPU, madencilikten önce hepsini tamamla.
                              2: Bir seferde üç GPU, madencilikten önce hepsini tamamla.
                              3: Tüm GPU'lar paralel, madenciliğe hemen başla.
      --pcie_fmt=FORMAT     PCIe bus numaralarının yazdırma biçimini ayarlar.  FORMAT için kabul edilen değerler
                              'hex' veya 'dec'dir.  Varsayılan Windows için dec, Linux için hex'tir.
      --bus_reorder         Algılanan veya belirtilen cihazları PCIe bus ID'lerine göre yeniden sıralar.  Platform
                              belirtilmezse cihazlar algılanan tüm AMD OpenCL platformlarından
                              toplanır.  Not: v0.7.0 sürümünden itibaren bu varsayılan davranıştır.
      --opencl_order        Algılanan veya belirtilen cihazları OpenCL'in sunduğu sırayla sıralar.
      --list_devices        Algılanan veya belirtilen platform için kullanılabilir cihazları listeler ve hemen
                              çıkar.  Bus yeniden sıralaması gösterilen sırada uygulanır.
      --nr_cu_override=X,Y,... OpenCL API'sinin sunduğu GPU başına hesaplama birimi (CU) sayısını geçersiz kılar. Bu
                              özellikle 56 BIOS'u yüklenmiş ve sürücünün gerçek sayı yerine 56 CU bildirdiği
                              Vega 64'ler için kullanışlıdır.  Argümanın değeri olarak GPU başına geçersiz kılınacak CU
                              sayısının virgülle ayrılmış bir listesini verin.  GPU'ları atlayabilirsiniz; rig'deki tüm
                              GPU'lar için değer vermeniz gerekmez.  1 ve 3 indeksli iki Vega ve iki başka GPU'dan oluşan
                              karışık bir rig için örnek: --nr_cu_override=,64,,64.  Madencilikten önce --list_devices
                              ekleyerek argümanınızı doğrulayabilirsiniz.

Frekans/voltaj kontrol seçenekleri (yalnızca Windows, BETA işlev):

                              Madenci yazılımı, çekirdek ve bellek frekanslarını ve ilgili voltajlarını ayarlamak
                              ve Windows sürücüsünün yerleşik timing'leri arasında seçim yapmak için temel işlevlere sahiptir.  Aşağıdaki
                              her argüman için rig'deki GPU('lar)ın değerlerini virgülle ayrılmış bir listede
                              sıralarsınız.  Bazı argümanlar belirli GPU'lar için kullanılmaz.  Listede GPU'ları atlayabilirsiniz.
                              Madenci yazılımı GCN GPU'larda (Polaris, Vega) hem çekirdek hem bellek için her zaman en yüksek
                              p-state'i ayarlar ve kullanır.  Rx Vega GPU'ların 900mV'tan düşük bir voltajla çalışabilmesi için
                              bellek p2 durumunda powerplay tablosu değişikliği yapılması _gerektiğini_ unutmayın.  Ayrıca Big Navi
                              GPU'ların powerplay tablosu değişiklikleri için, örneğin daha düşük voltaj ayarını etkinleştirmek
                              için, hâlâ MorePowerTool gibi bir araç kullanması gerekir.  Madenci yazılımı gelecekte powerplay
                              tablosuyla ilgili işlevlere destek _ekleyebilir_.
      --clk_debug                 Frekans/voltaj/timing ayarlarıyla ilgili başlangıç log çıktılarını etkinleştirir.
      --clk_core_mhz=MHZ1,MHZ2,... GPU başına çekirdek frekansını MHz cinsinden ayarlar.
      --clk_core_mv=MV1,MV2,...    GPU başına çekirdek voltajını mV cinsinden ayarlar.
      --clk_mem_mhz=MHZ1,MHZ2,...  GPU başına bellek frekansını MHz cinsinden ayarlar.
      --clk_mem_mv=MV1,MV2,...     GPU başına bellek voltajını mV cinsinden ayarlar.  Navi veya Big Navi GPU'larda kullanılmaz.
      --clk_timing=V1,V2,...       Sürücünün kullanılabilir bellek timing setleri arasında seçim yapar.  Tüm GPU'larda ve
                                   sürücülerde kullanılamaz.
                              Rx Vega 64, 580, 5700XT ve 6800 bulunan ve ethash veya benzerini kazan dört GPU'lu bir sistem
                              için kısmi komut satırı örneği.   Bellek voltajını yalnızca Vega ve 580 için belirtiyor, sürücü
                              timing değerini ise yalnızca Big Navi için seçiyoruz:
                              teamredminer.exe ... --clk_core_mhz=1100,1000,1275,1000 --clk_core_mv=875,850,725,675
                              --clk_mem_mhz=1107,2100,1820,2130 --clk_mem_mv=875,850,, --clk_timing=,,,1

Fan kontrol seçenekleri:

      --fan_control(=CFG1,CFG2,...)  Bu argüman, GPU fan kontrolünü madenci yazılımına verir.  TRM, GPU fan
                              hız(lar)ını çekirdek, junction ve/veya bellek sıcaklığına göre otomatik ayarlamayı destekler.
                              Yüzde cinsinden sabit bir fan hızı ayarlamayı da destekliyoruz.
                              Her GPU türünün varsayılan olarak kullanılacak bir fan yapılandırması vardır.  Hem GPU türü
                              başına varsayılan yapılandırmayı geçersiz kılmayı hem de rig'deki her GPU için ayrı
                              bir yapılandırma ayarlamayı destekliyoruz.
                              Bir fan yapılandırması ':' (iki nokta) karakteriyle ayrılmış (en fazla) altı değerden oluşur.  Değerler
                              şunlardır: hedef çekirdek sıcaklığı, hedef junction sıcaklığı, hedef bellek sıcaklığı, yüzde cinsinden
                              başlangıç fan hızı, yüzde cinsinden minimum fan hızı, yüzde cinsinden maksimum fan hızı.  Herhangi bir değer boş bırakılabilir.
                              Birkaç örnek:
                              ::70:50:25   Hedef bellek sıcaklığı 70C, fanı %50 hızda başlat, minimum fan hızı %25.
                              55::::20:80  Hedef çekirdek sıcaklığı 55C, fanı varsayılan yapılandırmadaki hızla başlat,
                                           fanı her zaman %20 ile %80 arasında tut.
                              55::75:80    Fanı çekirdek sıcaklığı <= 55C ve bellek sıcaklığı <= 75C olacak şekilde ayarla,
                                           fanı %80'de başlat.
                              :::100       Sabit fan hızını %100'e ayarla, sıcaklıklara göre asla değiştirme.
                              Bir GPU için kullanılan fan yapılandırması aşağıdaki öncelik sırasına göre belirlenir:
                              1. --fan_control argümanına bir yapılandırma listesi verildi ve listede X GPU'su için
                                 bir giriş var.
                              2. Bu GPU türünün varsayılan fan yapılandırması bir
                                 --fan_default_<type>=... parametresiyle geçersiz kılındı.
                              3. Bu GPU türü için yerleşik varsayılan fan yapılandırmasını kullan.
                              Yukarıdaki listede seçilen yapılandırmada fanın başlangıç değeri eksikse
                              sonraki yapılandırmadaki ayar kullanılır.
                              NOT: fan desteği beta bir özelliktir ve sürücülerin sağladığı destekten daha iyi
                              çalışmaz.  Örneğin Linux altındaki sürücüler çoğu zaman sysfs pwm desteğiyle bir fanı
                              %100'e zorlamaya izin vermez.
      --fan_default_polaris=CFG Tüm Polaris GPU'lar (450/460/550/560/470/480/570/580/590) için kullanılan varsayılan yapılandırmayı ayarlar.
                              Yerleşik varsayılan 55:::50'dir: 55C çekirdek sıcaklığı ve %50'de başlayan fan.
                              Not: bu ayar Tonga GPU'lar için de kullanılır.
      --fan_default_vega=CFG    Tüm Vega GPU'lar (Vega 56/Vega 64) için kullanılan varsayılan yapılandırmayı ayarlar.
                              Yerleşik varsayılan 55::70:50'dir: 55C çekirdek sıcaklığı, 70C bellek sıcaklığı ve %50 fan.
      --fan_default_vega2=CFG   Tüm Radeon VII GPU'lar için kullanılan varsayılan yapılandırmayı ayarlar.
                              Yerleşik varsayılan 70::75:80'dir: 70C çekirdek sıcaklığı, 75C bellek sıcaklığı ve %80 fan.
      --fan_default_navi=CFG    Tüm Navi (Navi10) GPU'lar için kullanılan varsayılan yapılandırmayı ayarlar.
                              Yerleşik varsayılan 60::80:70'tir: 60C çekirdek sıcaklığı, 80C bellek sıcaklığı ve %70 fan.
      --fan_default_big_navi=CFG  Tüm Big Navi (Navi21) GPU'lar için kullanılan varsayılan yapılandırmayı ayarlar.
                              Yerleşik varsayılan 50:::70'tir: 50C çekirdek sıcaklığı ve %70 fan. Bellek sıcaklığının
                              dahil edilmemesinin nedeni, Windows ADL kütüphanesinde sensörün eksik olmasıdır.
      --fan_debug             Ayarlamalarla ilgili log çıktılarını etkinleştirir.
      --fan_no_restore        Madenci yazılımından çıkışta orijinal fan profillerinin geri yüklenmesini devre dışı bırakır.

Watchdog seçenekleri:

      --no_gpu_monitor      Sıcaklık ve fan hızı için ADL (Windows) veya sysfs (Linux) GPU izlemesini
                              devre dışı bırakır.
      --temp_limit=TEMP     Madenci yazılımının aşırı ısınan GPU'ları durduracağı çekirdek sıcaklığını ayarlar.
                              Varsayılan 85C'dir.  GPU'ya özel değerler virgülle ayrılmış bir listeyle, GPU başına
                              bir değer olarak verilebilir.  Bir GPU için tanımlı değer yoksa listedeki ilk değer
                              kullanılır.
      --temp_resume=TEMP    Çekirdek sıcaklığının limiti aşması nedeniyle daha önce durdurulan GPU'ların madenci yazılımı
                              tarafından yeniden başlatılacağı çekirdek sıcaklığı eşiğini ayarlar.  Varsayılan 60C'dir.  GPU'ya özel
                              değerler virgülle ayrılmış bir listeyle, GPU başına bir değer olarak verilebilir.  Bir GPU için
                              tanımlı değer yoksa listedeki ilk değer kullanılır.
      --mem_temp_limit=TEMP Madenci yazılımının aşırı ısınan GPU'ları durduracağı bellek sıcaklığını ayarlar.
                              Varsayılan olarak etkin değildir.  Yalnızca GPU bir bellek sıcaklık sensörü sağlıyorsa kullanılır.
                              GPU'ya özel değerler virgülle ayrılmış bir listeyle, GPU başına bir değer olarak verilebilir.
                              Bir GPU için tanımlı değer yoksa listedeki ilk değer kullanılır.
      --mem_temp_resume=TEMP Bellek sıcaklığının limiti aşması nedeniyle daha önce durdurulan GPU'ların madenci yazılımı
                              tarafından yeniden başlatılacağı bellek sıcaklığı eşiğini ayarlar.  Varsayılan olarak etkin değildir.  Yalnızca
                              GPU bir bellek sıcaklık sensörü sağlıyorsa kullanılır.  GPU'ya özel değerler virgülle ayrılmış
                              bir listeyle, GPU başına bir değer olarak verilebilir.  Bir GPU için tanımlı değer yoksa
                              listedeki ilk değer kullanılır.
      --watchdog_script(=X) GPU watchdog'unu, madenci yazılımını kapatacak ve belirtilen betiği çalıştıracak şekilde
                              yapılandırır. Varsayılan betik geçerli dizindeki watchdog.bat/watchdog.sh'tir, ancak
                              isteğe bağlı bir argüman olarak, gerekirse mutlak veya göreli bir yolla birlikte, farklı
                              bir betik de verilebilir.
      --watchdog_test       Yapılandırılan watchdog betiğini, ~20 saniyelik madencilikten sonra ölü bir GPU ile aynı
                              eylemi tetikleyerek test eder.
      --watchdog_disabled   Watchdog'un çalışmamasını zorlar. Watchdog'un her zaman etkin olarak çalıştığı madencilik
                              işletim sistemlerinde watchdog'u devre dışı bırakmak için kullanılabilir.

Ethash seçenekleri:

      --eth_config=CONFIG   Madenci yazılımı için manuel ethash yapılandırması.  CONFIG [X][M][L] biçiminde olmalıdır.
                              [M] değeri modu seçer; 'A', 'B' veya 'C' olabilir.
                              'B' modu ek bellek kullanır ve yalnızca 8+GB kartlarda çalışır.
                              'C' modu ek bellek kullanır ve yalnızca VII gibi 16+GB kartlarda, doğru yapılandırılmış
                              bir sistemde çalışır.  Daha fazla ayrıntı için ETHASH_TUNING_GUIDE.txt dosyasına bakın.
                              [L] değeri yoğunluğu seçer ve aralığı GPU mimarisine bağlıdır.
                              [X] öneki isteğe bağlıdır ve yalnızca Navi/Big Navi içindir; daha fazla bellek işlemini etkinleştirir ve
                              daha düşük bir [L] ayar değerine yol açar. Otomatik ayarlayıcı tekrar tekrar GPU için mümkün olan
                              maksimum ayar değerine yakın bir değere ulaştığında faydalı olabilir.
                              Her iki değer de isteğe bağlıdır, ancak [L] belirtilirse [M] de belirtilmelidir.
                              Örnek yapılandırmalar: --eth_config=A
                                               --eth_config=B750
                                               --eth_config=XB
                              CONFIG, her biri ilgili GPU'ya uygulanan yapılandırma değerlerinin virgülle ayrılmış
                              bir listesi de olabilir. Örneğin: --eth_config=A,B750,,A288
                              Listede kendine özel yapılandırması olmayan her GPU, listedeki ilk
                              yapılandırmayı kullanır.
      --eth_variant_mode=X  Bu argüman, ecip-1099'da açıklandığı gibi ETC için epoch 390'dan itibaren ethash değişikliklerinin
                              etkinleştirilmesini kontrol eder. Kullanılabilir modlar:
                              pool      - Varsayılan mod. Yalnızca havuz etchash içeren bir algoritma bayrağı gönderirse etkinleşir.
                                          Bu bayrak görüldükten sonra, ethash içeren başka bir algoritma bayrağı alınmadıkça
                                          tüm havuz işlerinin etchash olduğu varsayılır.
                              etchash   - Etchash modu. Epoch >= 390 etchash, daha düşük epoch'lar ethash kabul edilir. Havuzun
                                          algoritma bayrakları kullanılmaz.
                              deduce    - Havuzun algoritma bayraklarını yok sayar ve yalnızca mevcut sistem saatine ve ETC ile ETH'nin
                                          bilinen yükseklik ve zamanlarına dayalı bir sezgisel yöntem uygular. Bu mod, ETH Ocak 2021'de
                                          epoch 390'a ulaştığında genel bir yaklaşım olarak çalışmalıdır. Sistem saatinin doğru olması gerekir.
                                          Alttaki havuzlara proxy yaparak ethash ve etchash işleri arasında serbestçe geçiş yapan
                                          kârlılık geçişi (profit switching) kurulumlarını da idare etmelidir.
                              auto      - Havuz bir algoritma bayrağı göndermediği sürece deduce modunu kullanır. Bir algoritma bayrağı
                                          görüldüğünde pool moduna geçer.
                              ethash    - Zorunlu ethash modu. ecip-1099 asla uygulanmaz.
                              force_etc - Zorunlu etchash modu. ecip-1099 kuralları her zaman uygulanır. ETC testnet madenciliği için kullanın.
      --eth_aggr_mode       --eth_config argümanıyla farklı bir yapılandırma verilmedikçe tüm Polaris 8GB kartlar için
                              'B' modunun otomatik kullanımını etkinleştirir.  Bu, rig'deki tüm Polaris 8GB GPU'ları
                              --eth_config ile manuel olarak 'B' moduna ayarlamakla aynı şeydir.
                              Çoğu GPU için bu, 0.1-0.2 MH/s hashrate ekler.  NOT: rig'lerin %20-25'i bu modda daha az
                              kararlı hâle gelir; varsayılan mod olmamasının nedeni budur.  Ölü GPU'larla
                              karşılaşırsanız bu argümanı kaldırmalı ve GPU'ları 'A' modunda çalıştırmalısınız.
      --eth_stratum_mode=MODE Ethash havuzları için sabit bir stratum modu ayarlar.  Varsayılan olarak madenci yazılımı
                              havuzun desteklediği stratum türünü otomatik olarak belirlemeye ve o modu kullanmaya çalışır.
                              Bu otomatik algılama, bu seçenek belirtilerek geçersiz kılınabilir.  MODE şu
                              seçeneklerden birine ayarlanabilir: stratum, nicehash, ethproxy.
      --eth_worker          Havuza gönderilecek worker ID'sini ayarlar.  Bu yalnızca ethproxy stratum modlu havuzlar
                              için geçerlidir.
      --eth_hash_report=X   Yapılandırılmış havuzlara gönderilen hashrate raporlarını kontrol eder.  Bu değer tüm havuzlara uygulanır. Değerler:
                              default   - her havuz için kullanılan stratum protokolüne göre madenci yazılımı karar verir.
                              force     - havuz reddetse bile her zaman hashrate raporu gönderir.
                              on        - ilk hashrate raporunu gönderir, mesajı reddeden havuzlar için devre dışı bırakır.
                              off       - asla hashrate raporu göndermez.
      --eth_epoch           Belirli bir ethash epoch'unu test eder. NOT: bu, tıpkı --benchmark eklemişsiniz gibi madenci yazılımını
                              otomatik olarak benchmark moduna geçirir.
      --eth_alloc_epoch=N   Başlangıçtan itibaren verilen epoch için yeterli bellek ayırır.  Madencilik sırasında daha sonra
                              gerekirse madenci yazılımı daha fazlasını ayırmaya çalışır.
      --eth_dag_buf=X,Y,... Madenci yazılımı DAG için tek veya çift tampon ayırabilir.  Şimdilik varsayılan AUTO'dur.  Tek
                              tampon biraz daha iyidir ve tüm GPU türlerinde küçük bir güç tasarrufu sağlar.  4GiB'den büyük tek
                              büyük ayırmaları yalnızca yeni sürücüler destekler; genellikle Adrenalin 20.9.1 ve amdgpu-pro 20.x'ten itibaren. Bu
                              argümanla madenci yazılımı mümkün olduğunda tek tampon modunu otomatik olarak kullanabilir veya GPU başına
                              tek ya da çift tamponu zorlayabilir.  Desteklenen değerler A(uto), S(ingle), D(ual)'dır.  Rig'deki tüm GPU'lar için
                              virgülle ayrılmış bir liste ya da tüm GPU'lar için tek bir değer verebilirsiniz.  Virgülle ayrılmış
                              listede değeri olmayan GPU ilk değeri kullanır.
      --eth_big_mode_adjust=X,Y,...  B- veya C-modları kullanılırken madenci yazılımı ne kadar çok VRAM ayırabilirse o kadar iyi çalışır.  Ne yazık ki
                              sürücüler, özellikle Windows'ta, ne kadar bellek ayrılabileceğini doğru bildirmez.
                              Madenci yazılımı, kullanılabilir VRAM boyutundan güvenli ve muhafazakâr bir pay olarak 256MiB (Linux) ve
                              512MiB (Windows) kullanır.  Bu sayıyı değiştirmek isterseniz bu argümanla, bir veya daha fazla GPU için
                              değerler içeren virgülle ayrılmış bir liste vererek yapabilirsiniz.  B/C-modunda çalışmayan GPU'ların değerleri
                              yok sayılır.  Bir GPU'nun listede değeri yoksa bunun yerine verilen ilk değer kullanılır.
                              İzin verilen aralık [-64, 2048]'dir. Sayı ne kadar yüksekse GPU'da o kadar az VRAM ayrılır.
      --eth_dag_slowdown=N  DAG oluşturmayı yavaşlatır.  0-9 arası tek bir rakam verin. 0 yavaşlatma yok demektir (<= 0.7.9 davranışı),
                              1 minimum yavaşlatma, 9 maksimum demektir.  Varsayılan değer: hafif bir yavaşlatma için 4.
      --eth_stagger         Yeni bir DAG oluşturulurken GPU'ların kademeli başlatılmasını etkinleştirir.  Bu, tüm GPU'larda aynı anda
                              %0'dan %100 yüke geçmekten hoşlanmayan PSU'lar için daha yumuşaktır.
      --eth_no_stagger      --eth_stagger'ı devre dışı bırakır.  0.7.18'den itibaren zaten varsayılan davranıştır.  Argüman yalnızca geriye
                              dönük uyumluluk için tutulmuştur.
      --eth_ramp_up         DAG oluşturma, GPU devre dışı bırakma/etkinleştirme veya ağ kesintisinden sonra tüm GPU'larda yoğunluğun kademeli artırılmasını ekler.
                              DAG oluşturma ile madenciliğin başlaması arasında çöken rig'lere yardımcı olabilir.
      --eth_no_ramp_up      --eth_ramp_up'ı devre dışı bırakır.  0.7.18'den itibaren zaten varsayılan davranıştır.  Argüman yalnızca geriye
                              dönük uyumluluk için tutulmuştur.
      --eth_direct_abort    Devam eden GPU işlerini iptal etmek için farklı bir mekanizma kullanır.  Bayat (stale) share'leri en aza indirmek için
                              ROCm ortamlarındaki Vega'lar için önerilir.  Yalnızca rig'deki Vega ve Polaris GPU'lara uygulanır.
      --eth_dag_alloc_patch Eski BIOS'lu bazı anakartlarda, genellikle sistemdeki ilk veya son GPU'da donanım hataları (hw err) görülebilir.
                              Sorunu çoğu zaman çözen yamalı bir DAG ayırma stratejisini zorlamak için bu argümanı kullanın.
                              BIOS'unuzu güncellemek de sorunu çoğu zaman çözer.
      --eth_hashwatch(=M,M) GPU'lar hash üretirken beklenen, MH/s cinsinden minimum/maksimum watchdog hashrate'ini tanımlar.  Bir GPU bu
                              aralığın dışında çok uzun kalırsa arızalı kabul edilir ve watchdog tetiklenir.  Varsayılan
                              minimum/maksimum değerler 2 MH/s ve 150 MH/s'dir.  Varsayılan değerlerle etkinleştirmek için
                              --eth_hashwatch kullanın.  Kendi değerlerinizi ayarlamak için örneğin --eth_hashwatch=1.25,60 kullanın.  Rig'deki tüm
                              GPU'lar için aynı aralık kullanılır.  Bir taraf için negatif değer o tarafı devre dışı bırakır; örneğin minimum kontrolü
                              olmadan, devasa sahte hashrate'lerle sonuçlanan GPU sıfırlamalarını yakalamak için --eth_hashwatch=-1,1000 kullanın.
      --eth_dag_cache(=EPOCH) Farklı epoch'lu işlerden gelen eth DAG'lerinin kaydedilmesini etkinleştirir; böylece eski epoch'lu işler
                              tekrar alınırsa gelecekte yeniden oluşturulmaları gerekmez.  GPU bellek alanı izin verirse en fazla bir DAG
                              kaydedilir.  Bu, eth+zil madenciliği gibi havuz geçişleri için kullanışlıdır.  Başlangıçta belirli bir epoch'u
                              hemen önceden oluşturmak istiyorsanız isteğe bağlı değeri ekleyin. Eth+zil geçişi yapan madenciler
                              --eth_dag_cache=0 kullanmalıdır.  Şu anda yalnızca ethash (etchash değil) epoch'ları önceden oluşturulabilir.
      --eth_dag_cache_resv=MEM  DAG önbelleği etkinken (bkz. --eth_dag_cache) madenci yazılımının kullanılmadan bırakmaya çalışacağı
                              GPU bellek miktarını ayarlar.  MEM argümanı, kullanılmadan bırakılacak bellek miktarıdır;
                              mebibayt cinsinden.  Varsayılan değer 256'dır.
      --eth_dag_cache_verify    DAG oluşturma tamamlandıktan sonra DAG önbelleğinin okunmasını ve doğrulanmasını etkinleştirir.  Bu, DAG
                              önbelleğinde bit hataları olduğu ve sonuçta oluşan DAG'in kısmen bozuk olduğu durumları algılar.  DAG
                              büyüdükçe bunun Vega'larda giderek daha sık yaşandığını gördük.  Algılandığında DAG önbelleği için
                              yeni bir tampon ayrılır ve DAG oluşturma yeniden başlatılır.
      --eth_micro_delay=VAL,VAL,...  GPU('lar)da iş yeniden kuyruğa alınırken bir gecikme (mikrosaniye cinsinden) ekler.
                              Çok sayıda GPU'yu besleyen zayıf PSU'lar, birden fazla GPU işi tam olarak aynı anda yeniden kuyruğa
                              aldığında bazen "slew rate"i kaldıramaz.  Bunu örneğin 32'ye ayarlamak, bu tür rig'lerde yüksüz durumdan
                              %100 yüke geçişi slew rate'i düşürecek kadar yumuşatır.  Bu sorunun tipik belirtisi, rig'in yanıt
                              vermez hâle geldiği ve yeniden başlatmak için gücün kesilip verilmesini gerektiren tam donmalardır, ancak
                              normal GPU çökmeleri de olabilir.  Geçerli değerler 0-256'dır.  GPU başına değerler virgülle ayrılmış bir listede verilebilir.
                              Listede değeri belirtilmemiş GPU'lar ilk değeri kullanır. Bu argümanın tek algoritmalı ethash
                              madenciliğindeki varsayılan değerleri:
                                Polaris: 64
                                Vega:    0
                                Navi:    0
      --eth_ignore_abort_fail   İş iptali başarısız olduğunda bu genellikle yoğunluğun çok yüksek olmasının sonucudur ve madenci yazılımı
                              bu nedenle onu otomatik olarak düşürür.  Bu seçenek bu mantığı _devre dışı bırakır_; yoğunluk korunur, bunun
                              yerine bir uyarı loglanır.
      --eth_no_job_logs         Havuz(lar)dan alınan yeni işlere ait tüm logları gizler.  Tüm ethash ailesi madencilik oturumlarına uygulanır,
                              yani dual eth+zil kurulumunda hem eth hem de zil havuzlarının logları gizlenir.  Yeni bir epoch'a
                              geçen havuz işleri yine de loglanır.
      --eth_smooth_power=X,Y,...  "Smooth power" zamanlama yaklaşımı 0.10.0'da eklendi ve tüm GPU türleri için kullanılabilir.
                              Genel olarak biraz hashrate ekleyen ve çoğu durumda kararlılığı da artıran iyi bir özelliktir ve
                              tüm GPU'larda varsayılan olarak etkindir.  Ancak buna iyi tepki vermeyen ve çökmeye başlayan
                              rig'ler vardır.  Böyle bir durumda bu argümanla özelliği rig'inizdeki her GPU için ayrı ayrı kontrol edebilirsiniz.
                              Geçerli değerler 0 veya 1'dir. 5 GPU'lu bir rig'de ilk ve son GPU'da smooth power'ı devre dışı bırakmak için
                              --eth_smooth_power=0,1,1,1,0 kullanabilirsiniz.  Bir GPU için değer belirtmezseniz listedeki ilk değer
                              kullanılır.  Bu, --eth_smooth_power=0 ile özelliği tüm rig için devre dışı bırakabileceğiniz anlamına gelir.

Progpow seçenekleri (kawpow, firopow):

      --prog_config=CONFIG  Madenci yazılımı için manuel progpow yapılandırması.  CONFIG [M][L] biçiminde olmalıdır.
                              [M] değeri modu seçer; 'A' veya 'B' olabilir.
                              'B' modu genellikle daha iyi performans sağlar, ancak yalnızca Linux'taki Vega ve
                              Navi (Linux veya Windows) için kullanılabilir.
                              [L] değeri yoğunluğu seçer ve aralığı GPU mimarisine bağlıdır.
                              Her iki değer de isteğe bağlıdır, ancak [L] belirtilirse [M] de belirtilmelidir.
                              Örnek yapılandırmalar: --prog_config=A
                                               --prog_config=B750
                              CONFIG, her biri ilgili GPU'ya uygulanan yapılandırma değerlerinin virgülle ayrılmış
                              bir listesi de olabilir. Örneğin: --prog_config=A,B750,,A288
                              Listede kendine özel yapılandırması olmayan her GPU ilkini kullanır.
      --prog_height=VALUE   Benchmark amacıyla progpow algoritmaları için sabit bir blok yüksekliği ayarlar.  Bu, madenci yazılımını
                              otomatik olarak benchmark moduna geçirir.
      --prog_strict         Madenci yazılımını her zaman tam doğrulukta çekirdekler (kernel) oluşturmaya zorlar.  Varsayılan olarak madenci
                              yazılımı daha az hesaplama gücü kullanan ancak ara sıra geçersiz share'lere yol açabilen
                              gevşetilmiş çekirdekler oluşturur.
      --prog_dag_slowdown=N  DAG oluşturmayı yavaşlatır.  0-9 arası tek bir rakam verin.  0 yavaşlatma yok demektir (<= 0.7.9 davranışı),
                              1 minimum yavaşlatma, 9 maksimum demektir.  Varsayılan değer: hafif bir yavaşlatma için 4.
      --prog_stagger         Bkz. --eth_stagger.
      --prog_ramp_up         Bkz. --eth_ramp_up.
      --prog_no_stagger      Bkz. --eth_no_stagger.
      --prog_no_ramp_up      Bkz. --eth_no_ramp_up.
      --prog_micro_tune=X,Y,... Bu seçenek, her yeni rastgele kod bloğu için kısa bir yeniden ayar oturumunu etkinleştirir.  Bu,
                               Polaris GPU'ların maksimum hızlarında çalışması için önemlidir.  Vega ve Navi'lerde genellikle performansı
                               artırmaz.  Varsayılan AUTO modu bunu tüm Polaris GPU'lar için etkinleştirir, diğerleri için devre dışı bırakır.
                               Devre dışı bırakmanın tek nedeni kararlılık olabilir.  Argüman değeri, GPU başına bir değer olmak üzere
                               virgülle ayrılmış bir değer listesidir.  Bir GPU'nun değeri eksikse ilk GPU'nun
                               değeri kullanılır.  Manuel bir prog_config ayarlamanın mikro ayarlayıcıyı da fiilen devre dışı
                               bıraktığını unutmayın.  Kullanılabilir değerler:
                               1 - bu GPU için progpow mikro ayarını KAPAT.
                               2 - bu GPU için progpow mikro ayarını AÇ.
                               3 - mikro ayarın etkinleştirilip etkinleştirilmeyeceğine madenci yazılımı karar versin (AUTO).
      --prog_hash_report    Tüm havuzlara gönderilen zorunlu hashrate raporunu (ethash'te olduğu gibi) etkinleştirir.  Bu,
                               --eth_hash_report=force için bir takma addır; progpow ve ethash aynı havuz protokol(ler)ini
                               kullandığından o da geçerlidir.

Cryptonight seçenekleri:

      --rig_id              Havuza gönderilecek rig tanımlayıcısını ayarlar. Bu yalnızca cryptonight havuzları
                              için kullanılır.
      --cn_config=CONFIG    Madenci yazılımı için manuel cryptonight yapılandırması.  CONFIG
                              [P][I0][M][I1][:xyz] biçiminde olmalıdır; burada [P] isteğe bağlı bir önek, [:xyz] ise
                              isteğe bağlı bir sonektir.  [P] için yalnızca Lexa/Baffin gibi giriş seviyesi GPU'lar için
                              'L' değeri desteklenir.  [I0] ve [I1] iş parçacığı yoğunluk değerleridir; normalde
                              1 ile 16 arasındadır, ancak 16GB GPU'larda daha büyük değerler mümkündür.  [M]
                              moddur; '.', -', '+' veya '*' olabilir.  '.' modu, madenci yazılımının en iyi modu
                              seçmesi veya taraması gerektiği anlamına gelir.  '*' modu hem iyi bir varsayılan moddur hem de
                              değiştirilmiş bellek timing'leriyle Vega 56/64'te kazı yapıyorsanız _kullanılmalıdır_.  Bu
                              kuralın istisnaları küçük pad varyantlarıdır (cnv8_trtl ve cnv8_upx2); bunlar
                              yine '+' kullanmalıdır. Polaris GPU'lar için yalnızca '-' ve '+' modları kullanılabilir.

                              NOT: TRM 0.5.0'da otomatik ayar işlevi eklendi; bu da nadir uç durumlar dışında CN
                              yapılandırma modlarının manuel olarak ayarlanmasını gereksiz kıldı.  Daha fazla bilgi için
                              sürümle birlikte gelen ayar belgelerine ve nasıl yapılır belgelerine bakın.

                              Örnek yapılandırmalar: --cn_config=15*15:AAA
                                               --cn_config=14-14
                                               --cn_config=L4+3
                              CONFIG, her biri ilgili GPU'ya uygulanan yapılandırma değerlerinin virgülle ayrılmış
                              bir listesi de olabilir. Örneğin: --cn_config=8-8,16+14:CBB,15*15,14-14
                              Listede kendine özel yapılandırması olmayan her GPU, listedeki ilk
                              yapılandırmayı kullanır.
      --no_cpu_check        Bulunan share'lerin havuza gönderilmeden önce CPU ile doğrulanmasını devre dışı bırakır.
                              Not: şu anda yalnızca CN algoritmaları CPU doğrulamasını destekler.
      --no_lean             Başlangıçta veya ağ sorunları ya da GPU sıcaklık kısıtlaması sonrasında yeniden başlatmada iş
                              parçacıklarının yavaşça artırıldığı CN lean modunu devre dışı bırakır.
      --no_interleave=DEVS  CN iş parçacığı interleave mantığının kullanılmaması gereken GPU cihazlarını listeler.
                              Argüman, -d seçeneğindeki gibi virgülle ayrılmış bir cihaz listesidir.
                              Bazı cihaz(lar) çok sayıda interleave ayar log mesajıyla birlikte daha kötü bir hashrate
                              alıyorsa bu argümanı kullanın.
      --alloc_patch=DEVS    TRM v0.4.5 ile sonraki sürümler arasında hashrate kaybeden GPU cihazlarını listeler. Bu
                              argümanla daha basit bir bellek ayırma stratejisi kullanılır ve eski (daha yüksek) hashrate'in
                              geri gelmesi beklenir. Otomatik ayar modu yine kullanılabilir.
      --auto_tune=MODE      Başlangıçta otomatik ayar modunu etkinleştirir. Yalnızca CN varyantları için kullanılabilir. MODE
                              NONE, QUICK veya SCAN olmalıdır. QUICK modu bilinen birkaç iyi yapılandırmayı kontrol eder
                              ve 1 dakika içinde tamamlanır. SCAN modu tüm olası kombinasyonları kontrol eder ve
                              20-30 dakika sürer. MODE'u NONE olarak ayarlamak otomatik ayar özelliğini devre dışı bırakır. Varsayılan
                              mod QUICK'tir.
      --auto_tune_runs(=N)  Otomatik ayar için birden fazla tur çalıştırır; her seferinde iş parçacıklarından birinde kullanılan
                              pad birimini -1 azaltır (15+15 -> 15+14 -> 14+14 -> 14+13 -> ...). Tur sayısını
                              açıkça belirtebilir veya GPU türüne göre varsayılan bir değeri (genellikle 3-4) madenci yazılımına seçtirebilirsiniz.
      --auto_tune_exit      Belirtilirse madenci yazılımı otomatik ayar sürecini tamamladıktan sonra çıkar. Bu, en uygun
                              ayarları taramak ve ardından madenci yazılımının yazdırdığı sonuç komut satırı argümanını
                              kullanmak istediğinizde faydalıdır.
      --allow_large_alloc   Belirtilirse ve sürücü yeterli GPU VRAM'i olduğunu bildirirse madenci yazılımı ilk bellek
                              ayırmada daha agresif davranır. Pratikte bu seçenek, Linux altındaki Vega GPU'ların
                              otomatik ayar sürecine 16*14 veya 15*15 yerine 16*15'ten başlaması
                              anlamına gelir.

MTP seçenekleri:

      --allow_all_devices   Bazı algoritmalar örneğin 4GB GPU'larda kazılamaz. Bu GPU'lar madenci yazılımı tarafından
                              otomatik olarak devre dışı bırakılır. Bu argüman bu mantığı geçersiz kılar ve belirtilen veya
                              algılanan tüm cihazlarda madenciliğe izin verir.

X16* seçenekleri:

      --hash_order=VALUE    Benchmark amacıyla x16r gibi algoritmalar için sabit bir hash sırası ayarlar.
                              Bu ayar madenci yazılımını otomatik olarak benchmark moduna geçirir.
                              x16r için standart benchmark hash sırası --hash_order=0123456789abcdef'tir.

Nimiq seçenekleri:

      --nimiq_worker=VALUE  Nimiq için havuz(lar)a iletilecek worker/cihaz adını ayarlar.
      --nimiq_no_proxy      Ayrı bir işlem olarak çalıştırılan otomatik Nimiq proxy'sini devre dışı bırakır. Bu,
                              madenci yazılımına verilen host ve portun bir proxy'yi göstermesi gerektiği anlamına gelir.
      --nimiq_proxy=VALUE   Nimiq proxy'sinin varsayılan yolunu geçersiz kılar. Varsayılan, geçerli madenci yazılımı dizinindeki
                              trm_nimiq_proxy-win.exe ve trm_nimiq_proxy-linux'tur.
      --nimiq_port=VALUE    Nimiq proxy'si için kullanılan varsayılan yerel portu (4444) geçersiz kılar. Sisteminiz 4444
                              portunu zaten başka bir TCP/IP hizmeti için kullanıyorsa bu kullanılabilir.

Verthash seçenekleri:

      --verthash_file=FILE  Verthash veri dosyasını yüklemek/kaydetmek için kullanılacak dosya adını ayarlar.  Bu seçenek
                              verthash algoritması kullanılırken belirtilirse madenci yazılımı verthash verilerini dosyadan
                              yüklemeye çalışır.  Dosya yoksa madenci yazılımı verthash verilerini oluşturur
                              ve ileride kullanmak üzere dosyaya kaydeder.  Bu seçenek belirtilmezse
                              madenci yazılımı her başlangıçta verthash verilerini sistem belleğinde oluşturur.
      --verthash_max_uploads=N  Bazı anakartlar, rig'deki tüm GPU'ların verthash tablosunu aynı anda yüklemesiyle
                              sorun yaşar.  Bu argüman, başlangıçta tabloyu aynı anda yükleyen eşzamanlı GPU
                              sayısını sınırlar.  İzin verilen değerler 1-32'dir.  Varsayılan değer 4'tür.

Autolykos2 seçenekleri:

      --autolykos_mem_adjust=N  Madenci yazılımının autolykos için GPU tamponları ayırırken kullanılmadan bırakması gereken
                              bellek miktarını MiB cinsinden ayarlar.  Varsayılan değer Linux'ta 384, Windows'ta 512'dir.  Ekran
                              bağlı GPU'lar için varsayılan 512 artırılır.  ZIL ile dual madencilik yapılıyorsa
                              varsayılan değer 1024 artırılır.  Seçenek, her değeri ilgili GPU'ya uygulanan virgülle
                              ayrılmış bir değer listesiyle de verilebilir.  Listede boş bir değer belirtilirse
                              o GPU için varsayılan kullanılır.  Bir GPU için değer belirtilmezse
                              listedeki ilk değeri kullanır.  Kullanılan VRAM miktarı hem ana tamponları hem de
                              bir sonraki yükseklik için önceden oluşturulan tamponları barındırmalıdır.  Örneğin:
                                    --autolykos_mem_adjust=256,512,,256
      --autolykos_prebuild=N  Bir sonraki yükseklik için pad'in önceden oluşturulma hızını yapılandırır.  Daha yüksek bir değer daha hızlı
                              ön oluşturma demektir, ancak ön oluşturma sürdüğü müddetçe daha büyük güç dalgalanmaları ve muhtemelen
                              daha büyük bir hashrate düşüşü olur.  Geçerli değerler 0-9'dur; 0 hiç ön oluşturma yok, 9 ise en hızlı varyant demektir.
                              Varsayılan değer GPU'ya bağlı olarak 3 veya 4'tür.  Tüm GPU'lar için tek bir değer
                              ya da GPU başına virgülle ayrılmış bir değer listesi belirtebilirsiniz.
      --autolykos_slowdown=N  Pad oluşturma sürecine yavaşlatma ekler.  Geçerli değerler 0-100'dür. Varsayılan 0'dır, yani
                              yavaşlatma yok.
      --autolykos_ignore_diff Havuzun gönderdiği zorluğu yok sayar ve yalnızca işlerde verilen 256 bit hedefi kullanır.
                              Bazı havuzlar ERGO referans madenci yazılımının havuz uygulamasını izlemez; bu durumda bu
                              argüman yardımcı _olabilir_. NOT: bu tüm havuzlara uygulanır.

ZIL dual madencilik seçenekleri:

      --zil_start veya --zil  ZIL dual madencilik yapılandırmasını başlatır.  Bu argüman ile --zil_end işareti arasındaki tüm argümanlar
                              birincil algoritma yerine ZIL madenciliğine uygulanır.  Birincil algoritmanın önceki argümanlarda
                              ayarlanmış olması beklenir.  Amaç, çalışan herhangi bir TRM algoritma yapılandırmasına bir --zil ... --zil_end
                              yapılandırması ekleyebilmeniz ve her şeyin kutudan çıktığı gibi çalışmasıdır.
                              Bu argüman, ZIL için kullanmak isteyeceğiniz bir dizi varsayılan ayarı otomatik olarak yapar:
                               - ZIL epoch 0 DAG'inin önbelleğe alınmış kopyası.
                               - ZIL DAG'ine yer açmak için birincil algoritmaya ayrılan belleğin ayarlanması.
                               - ZIL madenciliği için ethash A-modunun seçilmesi.
                              Çalışan minimum kurulum, yalnızca madenci yazılımının birincil coin işlerini yok sayıp yalnızca ZIL
                              pencerelerinde kazı yapmasını kabul eden bir ZIL havuzu vermektir.  ezil.me için bir örnek:
                              --zil -o stratum+tcp://eu.ezil.me:5555 -u <eth wallet>.<zil wallet>.<worker name> -p x --zil_end
                              Daha fazla bilgi için TRM sürümüyle birlikte gelen ZIL dual madencilik kılavuzunu okuyun.
      --zil_end             ZIL madencilik yapılandırmasının bittiğini ve sonraki tüm argümanların birincil algoritmaya
                              ait olduğunu belirtir.  Bu argüman kesinlikle gerekli değildir, ancak madencilik dağıtımları için
                              eklenmelidir, çünkü kullanıcı dağıtımın komut satırının sonuna otomatik olarak hangi argümanları
                              ekleyeceğinden emin olamaz.
      --stats_mode=single/dual  ZIL dual madenciliği eklendiğinde, istatistik çıktısı varsayılan olarak ZIL madenciliğine ait
                              bilgileri eklemek için çoğaltılır.  TRM çıktısını veya log dosyalarını ayrıştıran bazı ortamlar
                              bununla karışıklık yaşayabilir.  Varsayılan çıktıya geçmek için --stats_mode=single ekleyin.

TON seçenekleri:

      --ton_pool_mode=X     Kullanılan TON madencilik lehçesini belirtir.  Ayarlanmazsa madenci yazılımı doğru seçimi havuzun
                              host adından çıkarmaya çalışır.  Kullanılabilir seçenekler:
                              toncoinpool - toncoinpool için stratum wss protokolünü kullan.
                              icemining   - ice mining'in TCP/IP üzerinden stratum protokolünü kullan.
                              tonpool     - tonpool'un, ice mining stratum protokolünün wss üzerinden çalışan sürümünü kullan.
      --wss_force_proxy     Madencilik protokolünü wss üzerinden çalıştıran TON havuzları için ayrı bir işlem olarak çalıştırılan
                              otomatik wss proxy'sini zorla etkinleştirir.  Madenci yazılımı bunu normalde otomatik olarak etkinleştirir, ancak bağlantı
                              için ham bir IP adresi veya takma host adı kullanılıyorsa bu argüman gerekli olabilir.
      --wss_no_proxy        Madencilik protokolünü wss üzerinden çalıştıran TON havuzları için ayrı bir işlem olarak çalıştırılan
                              otomatik wss proxy'sini devre dışı bırakır. Bu, madenci yazılımına verilen host ve portun bir proxy'yi
                              göstermesi gerektiği anlamına gelir.
      --wss_proxy=VALUE     wss proxy'sinin varsayılan yolunu geçersiz kılar. Varsayılan, geçerli madenci yazılımı dizinindeki
                              trm_nimiq_proxy-win.exe ve trm_nimiq_proxy-linux'tur, çünkü başlangıçta yalnızca
                              Nimiq için kullanılıyordu.
      --wss_port=VALUE      wss proxy'si için kullanılan varsayılan yerel portu (4444) geçersiz kılar. Sisteminiz 4444
                              portunu zaten başka bir TCP/IP hizmeti için kullanıyorsa bu kullanılabilir.

Ethash dual madencilik seçenekleri:

      --ton_start veya --ton  TON dual madencilik yapılandırmasını başlatır.  Bu argüman ile --ton_end işareti arasındaki tüm argümanlar
                              birincil algoritma (genellikle ethash) yerine TON madenciliğine uygulanır.  ethash'in önceki
                              argümanlarda ayarlanmış olması beklenir.  Amaç, çalışan herhangi bir TRM algoritma yapılandırmasına bir --ton ... --ton_end
                              yapılandırması ekleyebilmeniz ve her şeyin kutudan çıktığı gibi çalışmasıdır.
                              Çalışan minimum kurulum yalnızca bir TON havuzu vermektir.  Desteklenen havuzlar hakkında bilgi için
                              TON madencilik kılavuzunu okuyun. icemining için, beta havuz adresini kullanan bir örnek:
                              --ton -o stratum+tcp://ton.hashrate.to:4003 -u <ton wallet>.<worker name> -p x --ton_end
                              Daha fazla bilgi için TRM sürümüyle birlikte gelen TON dual madencilik kılavuzunu okuyun.
      --ton_end             TON madencilik yapılandırmasının bittiğini ve sonraki tüm argümanların birincil algoritmaya
                              ait olduğunu belirtir.  Bu argüman kesinlikle gerekli değildir, ancak madencilik dağıtımları için
                              eklenmelidir, çünkü kullanıcı dağıtımın komut satırının sonuna otomatik olarak hangi argümanları
                              ekleyeceğinden emin olamaz.
      --kas_start veya --kas  Kaspa dual madencilik yapılandırmasını başlatır.  Bu argüman ile --kas_end işareti arasındaki tüm argümanlar
                              birincil algoritma (genellikle ethash) yerine Kaspa madenciliğine uygulanır.  ethash'in önceki
                              argümanlarda ayarlanmış olması beklenir.  Amaç, çalışan herhangi bir TRM algoritma yapılandırmasına bir --kas ... --kas_end
                              yapılandırması ekleyebilmeniz ve her şeyin kutudan çıktığı gibi çalışmasıdır.
                              Çalışan minimum kurulum yalnızca bir Kaspa havuzu vermektir.  Bir örnek:
                              --kas -o stratum+tcp://pool.woolypooly.com:3112 -u <kaspa wallet>.<worker name> -p x --kas_end
      --kas_end             Kaspa madencilik yapılandırmasının bittiğini ve sonraki tüm argümanların birincil algoritmaya
                              ait olduğunu belirtir.  Bu argüman kesinlikle gerekli değildir, ancak madencilik dağıtımları için
                              eklenmelidir, çünkü kullanıcı dağıtımın komut satırının sonuna otomatik olarak hangi argümanları
                              ekleyeceğinden emin olamaz.
      --dual_intensity=X,Y,Z,... Bu argüman dual madenciliğin yoğunluğunu 0.0 ile 1.0 arasında bir katsayıyla ayarlar; 1.0
                              dual algoritmayı mümkün olduğunca fazla çalıştırmak demektir.  Bu seçenek, ethash hashrate'ini de
                              etkileyecek olan çekirdek frekansını düşürmeden güç çekişini aşağı zorlamak için önerilir.

                              Argüman ya tek bir genel değer ya da GPU başına bir değer listesi olarak verilir.  Örnekler:

                                --dual_intensity=0.75            Tüm GPU'lar, mümkün olan maksimum TON GPU kullanılabilirliğinin %75'ini kullanır.
                                --dual_intensity=0.75,1.0,0.5    Rig'deki ilk üç GPU için ayrı değerler; kalan GPU'lar
                                                                 %75 için ilk değeri kullanır.

      --dual_tuner_step=X   Dual ayarlayıcının farklı eth yapılandırma yoğunluklarını denerken kullanacağı adım boyutunu ayarlar.  Daha düşük
                              bir değer daha doğru sonuçlar demektir, ancak daha uzun da sürer.  Geçerli değerler 1,2,4,8,16,32,64'tür.
      --dual_tuner_period=X Dual ayarlayıcının denenen her yapılandırma için kaç saniye çalışacağını ayarlar.  Varsayılan 7 saniyedir.
      --dual_tuner_weights=X:Y:Z  Dual madencilik ayarlayıcısının, birincil ve dual algoritmanın 1 MH/s'sinin ne kadar değerli olduğunu
                              gösteren puanlama ağırlıklarına ihtiyacı vardır.  Madenci yazılımında, her algoritma uygulanıp eklendiğinde geçerli
                              olan varsayılanlar yerleşiktir, ancak ağ hashrate'leri ve piyasa fiyatları değiştikçe yeni değerler vermek gerekebilir.
                              Bu argüman, hepsinin pozitif sayı olması beklenen üç değer alır:
                                X    Birincil algoritmanın (genellikle ethash) 1 MH/s'si için puan.
                                Y    İkincil algoritmanın (genellikle TON veya Kaspa) 1 MH/s'si için puan.
                                Z    Ölçülen gücün 1 W'ı başına maliyet. Şimdilik bunu sıfır olarak ayarlamanızı öneririz.
                              ETH+TON için örnek:
                                Manuel göreli değere göre: ETH'nin her MH/s'si TON/Kaspa'nın 100 MH/s'sine eşdeğerdir
                                --dual_tuner_weights=100:1:0
                                Madencilik hesaplayıcılarına göre: 1 MH/s ETH için $0.0437, 1 MH/s TON/Kaspa için $0.0005476
                                --dual_tuner_weights=0.0437:0.0005476:0

FPGA seçenekleri:

      --fpga_devices=LIST   Algılanan listeden kullanılacak FPGA cihazlarını ayarlar. LIST, --list_devices'ın gösterdiği cihaz
                              indekslerinin veya cihaz DNA'larının virgülle ayrılmış bir listesi olmalıdır.
                                Örnekler:   -d 0,1,2,4
                                            -d 40020000013ae32135111111,40020000013ae32135222222,40020000013ae32135333333
                              Belirtilmezse kullanılabilir tüm FPGA cihazları kullanılır.
      --fpga_clk_core=LIST  FPGA cihazlarının çekirdek frekanslarını ayarlar.  Frekanslar, megahertz cinsinden
                              virgülle ayrılmış bir değer listesi olarak verilmelidir; her değer ilgili FPGA cihazına uygulanır.
                              Liste toplam cihaz sayısından kısaysa kalan cihazlar listedeki
                              ilk değeri kullanır.  Örneğin --fpga_clk_core=600,620, FPGA 0'a 600MHz, FPGA 1'e
                              620MHz uygular.  FPGA 2+ cihazları varsa bunlar 600MHz'e ayarlanır.
      --fpga_clk_mem=LIST   FPGA cihazlarının bellek frekanslarını ayarlar.  Biçim --fpga_clk_core ile aynıdır.
      --fpga_vcc_int=LIST   Destekleyen kartlarda vcc_int voltajını ayarlar.  Voltaj değerleri milivolt (mV) cinsinden
                              virgülle ayrılmış bir değer listesi olarak verilmelidir; her değer ilgili karta uygulanır.
                              Liste toplam cihaz sayısından kısaysa kalan cihazlar listedeki
                              ilk değeri kullanır.  Örneğin --fpga_vcc_int=700,800, FPGA 0'a 700mV vcc_int, FPGA 1'e
                              800mV vcc_int uygular.  FPGA 2+ cihazları varsa bunlar 700mV'a ayarlanır.
      --fpga_vcc_bram=LIST  Destekleyen kartlarda vcc_bram voltajını ayarlar.  Biçim --fpga_vcc_int ile aynıdır.
      --fpga_vcc_mem=LIST   Destekleyen kartlarda bellek/HBM voltajını ayarlar.  Biçim --fpga_vcc_int ile aynıdır.
      --fpga_update_fw      Çalışma zamanında voltaj kontrolü gibi özellikleri desteklemek için özel TRM firmware'li C1100
                              kartlarında uydu denetleyici firmware'inin güncellenmesini etkinleştirir. Yalnızca
                              --fpga_devices seçeneğiyle seçilen ve en son firmware sürümünü çalıştırmayan kartlar güncellenir.
                              ***** DİKKAT: Kullanıcılar firmware güncelleme sürecini kesintiye uğratmamaya dikkat etmelidir! *****
                              *****   Kesinti, kurtarılması çok zor olan, tuğlaya dönmüş bir kartla sonuçlanabilir.      *****
      --fpga_allow_unsafe=LIST Belirtilen FPGA'lar için varsayılan güvenlik limitlerini devre dışı bırakır.  Cihazlar
                              virgülle ayrılmış bir DNA değerleri listesiyle belirtilir, ör. --fpga_allow_unsafe=40020000013ae32135111111
                              ***** DİKKAT: Güvenlik limitlerinin üzerinde çalışmak cihazda KALICI HASARA yol açabilir!  *****
      --fpga_tcore_limit=LIST FPGA cihazlarının çekirdek sıcaklığı yumuşak limitlerini ayarlar.  FPGA çekirdek sıcaklığı
                              belirtilen değeri aşarsa madenci yazılımı, çekirdek sıcaklığını belirtilen değerin altına indirmek için
                              FPGA frekanslarını düşürür.  Değerler santigrat derece cinsindendir; liste biçimi --fpga_clk_core'a benzer.
      --fpga_tmem_limit=LIST FPGA cihazlarının bellek sıcaklığı yumuşak limitlerini ayarlar.  Açıklama için --fpga_tcore_limits'e bakın.
      --fpga_ivccint_limit=LIST VCCINT voltaj regülatörü akımı yumuşak limitlerini ayarlar.  Açıklama için --fpga_tcore_limits'e bakın.
      --fpga_ivccbram_limit=LIST VCCBRAM voltaj regülatörü akımı yumuşak limitlerini ayarlar.  Açıklama için --fpga_tcore_limits'e bakın.
      --fpga_max_jtag_mhz=XY.Z  FPGA JTAG iletişimi için kullanılacak izin verilen maksimum frekansı ayarlar.  Varsayılan 30.0 MHz'dir.
      --fpga_eth_clk_dag=LIST Ethash DAG oluşturma sırasında kullanılacak FPGA çekirdek frekanslarını ayarlar. Varsayılan olarak bunlar
                              normal çekirdek frekansının %90'ına ayarlanır. Biçim --fpga_clk_core ile aynıdır.

İndir Team Red Miner

0.10.21